summaryrefslogtreecommitdiffstats
path: root/languages/java/app_templates
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
commitf78eb03afb8c9a380985d26286afc40b4c89b292 (patch)
tree3c087e2f119e645c902958c3bc3c802abf078ad0 /languages/java/app_templates
parentda1941ccadffe5ae70ee111c53f0ec2b3d990869 (diff)
downloadtdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.tar.gz
tdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'languages/java/app_templates')
-rw-r--r--languages/java/app_templates/kappjava/app.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/languages/java/app_templates/kappjava/app.java b/languages/java/app_templates/kappjava/app.java
index d6424f73..40bc6b93 100644
--- a/languages/java/app_templates/kappjava/app.java
+++ b/languages/java/app_templates/kappjava/app.java
@@ -14,7 +14,7 @@ import org.kde.koala.*;
* @author $AUTHOR <$EMAIL>
* @version $APP_VERSION
*/
-public class %{APPNAME} extends KMainWindow
+public class %{APPNAME} extends TDEMainWindow
{
private %{APPNAME}View m_view;
private QPrinter m_printer;
@@ -27,7 +27,7 @@ public class %{APPNAME} extends KMainWindow
// accept dnd
setAcceptDrops(true);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions
@@ -88,7 +88,7 @@ public void setupActions()
// this doesn't do anything useful. it's just here to illustrate
// how to insert a custom menu and menu item
- KAction custom = new KAction(tr("Cus&tom Menuitem"), new KShortcut(),
+ TDEAction custom = new TDEAction(tr("Cus&tom Menuitem"), new TDEShortcut(),
this, SLOT("optionsPreferences()"),
actionCollection(), "custom_action");
}
@@ -27,7 +27,7 @@ public class %{APPNAME} extends KMainWindow
// accept dnd
setAcceptDrops(true);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions